.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`exposure`
=======================
.. automodule:: skimage.exposure

.. currentmodule:: skimage.exposure
.. autosummary::

   skimage.exposure.adjust_gamma
   skimage.exposure.adjust_log
   skimage.exposure.adjust_sigmoid
   skimage.exposure.cumulative_distribution
   skimage.exposure.equalize_adapthist
   skimage.exposure.equalize_hist
   skimage.exposure.histogram
   skimage.exposure.is_low_contrast
   skimage.exposure.match_histograms
   skimage.exposure.rescale_intensity



adjust_gamma
------------

.. autofunction:: skimage.exposure.adjust_gamma


.. include:: skimage.exposure.adjust_gamma.examples

adjust_log
----------

.. autofunction:: skimage.exposure.adjust_log


.. include:: skimage.exposure.adjust_log.examples

adjust_sigmoid
--------------

.. autofunction:: skimage.exposure.adjust_sigmoid


.. include:: skimage.exposure.adjust_sigmoid.examples

cumulative_distribution
-----------------------

.. autofunction:: skimage.exposure.cumulative_distribution


.. include:: skimage.exposure.cumulative_distribution.examples

equalize_adapthist
------------------

.. autofunction:: skimage.exposure.equalize_adapthist


.. include:: skimage.exposure.equalize_adapthist.examples

equalize_hist
-------------

.. autofunction:: skimage.exposure.equalize_hist


.. include:: skimage.exposure.equalize_hist.examples

histogram
---------

.. autofunction:: skimage.exposure.histogram


.. include:: skimage.exposure.histogram.examples

is_low_contrast
---------------

.. autofunction:: skimage.exposure.is_low_contrast


.. include:: skimage.exposure.is_low_contrast.examples

match_histograms
----------------

.. autofunction:: skimage.exposure.match_histograms


.. include:: skimage.exposure.match_histograms.examples

rescale_intensity
-----------------

.. autofunction:: skimage.exposure.rescale_intensity


.. include:: skimage.exposure.rescale_intensity.examples

